@@ -3,7 +3,7 @@
 PREFIX="$1"
 shift
 OPTIMIZE="$*"
-OPTIMIZE1=`echo "$*" | sed -s 's;enable-sse2;enable-sse;'`
+OPTIMIZE1=`echo "$*" | sed 's;enable-sse2;enable-sse;'`
 echo "Optimization for double" ${OPTIMIZE}
 echo "Optimization for single" ${OPTIMIZE1}
 
@@ -11,11 +11,13 @@ PFFT_VERSION=1.0.8-alpha2-fftw3
 TMP="tmp-pfft-$PFFT_VERSION"
 LOGFILE="build.log"
 
-mkdir $TMP 
+mkdir -p $TMP 
 ROOT=`dirname $0`/../
 if ! [ -f $ROOT/depends/pfft-$PFFT_VERSION.tar.gz ]; then
-wget https://github.com/rainwoodman/pfft/releases/download/$PFFT_VERSION/pfft-$PFFT_VERSION.tar.gz \
-    -O $ROOT/depends/pfft-$PFFT_VERSION.tar.gz 
+echo curl -o $ROOT/depends/pfft-$PFFT_VERSION.tar.gz \
+https://github.com/rainwoodman/pfft/releases/download/$PFFT_VERSION/pfft-$PFFT_VERSION.tar.gz
+curl -L -o $ROOT/depends/pfft-$PFFT_VERSION.tar.gz \
+https://github.com/rainwoodman/pfft/releases/download/$PFFT_VERSION/pfft-$PFFT_VERSION.tar.gz
 fi
 
 gzip -dc $ROOT/depends/pfft-$PFFT_VERSION.tar.gz | tar xf - -C $TMP
